library(startR)
library(ClimProjDiags)
dataset <- "/esarchive/recon/ecmwf/era5/daily_mean/$var$_f1h/$var$_$sdate$.nc"
sdates <- c(as.Date("1990-10-01") + c(0, 31, 30), 
            as.Date("1991-10-01") + c(0, 31, 30), 
            as.Date("1992-10-01") + c(0, 31, 30))

tasmax <- Start(dataset = dataset,
                var = 'tasmax',
                sdate = format(sdates, "%Y%m"),
                time = 'all',
                longitude = indices(1:10),
                latitude = indices(1:20),
                return_vars = list(time = NULL, latitude = NULL, longitude = NULL),
                num_procs = 4, retrieve = FALSE,
                synonims=list(longitude = c('lon', 'longitude'), latitude = c('lat', 'latitude')))
tasmin <- Start(dataset = dataset,
                var = 'tasmin',
                sdate = format(sdates, "%Y%m"),
                time = 'all',
                longitude = indices(1:10),
                latitude = indices(1:20),
                return_vars = list(time = NULL, latitude = NULL, longitude = NULL),
                num_procs = 4, retrieve = FALSE,
                synonims=list(longitude = c('lon', 'longitude'), latitude = c('lat', 'latitude')))


a <- DTRRef(tmax, tmin, by.seasons = FALSE, ncores = NULL)

step <- Step(DTRRef,
             target_dims = list(tasmax = c('time'), tasmin = c('time')),
             output_dims = list(dtr.ref = c('time')),
             use_attributes = list(tasmax = "Variables", tasmin = "Variables"))

workflow <- AddStep(list(tasmax = tasmax, tasmin = tasmin), step, by.seasons = TRUE)

res <- Compute(workflow,
               chunks = list(latitude = 2, longitude = 2),
               threads_load = 2,
               threads_compute = 4)




